@@ -1,23 +1,20 @@
-## wrap clipr::clipr_available() so I can mock it
+interactive <- function(...) {
+  stop("In this house, we use rlang::is_interactive()")
+}
+
+## wrap clipr::clipr_available() so I can tweak its behaviour
 clipboard_available <- function() {
-  if (Sys.getenv("CLIPBOARD_AVAILABLE", unset = TRUE)) {
-    return(clipr::clipr_available())
+  if (is_interactive()) {
+    clipr::clipr_available()
+  } else {
+    isTRUE(as.logical(Sys.getenv("CLIPR_ALLOW", FALSE)))
   }
-  FALSE
-}
-
-is_testing <- function() {
-  identical(Sys.getenv("TESTTHAT"), "true")
-}
-
-interactive <- function() {
-  base::interactive() && !is_testing()
 }
 
 ## returns TRUE if user says "no"
 ##         FALSE otherwise
 nope <- function(..., yes = "yes", no = "no") {
-  if (interactive()) {
+  if (is_interactive()) {
     cat(paste0(..., collapse = ""))
     return(utils::menu(c(yes, no)) == 2)
   }
@@ -27,7 +24,7 @@ nope <- function(..., yes = "yes", no = "no") {
 ## returns TRUE if user says "yes"
 ##         FALSE otherwise
 yep <- function(..., yes = "yes", no = "no") {
-  if (interactive()) {
+  if (is_interactive()) {
     cat(paste0(..., collapse = ""))
     return(utils::menu(c(yes, no)) == 1)
   }
